@@ -1,10 +1,10 @@
 import asyncio
 import time
 
-_DEFAULT_BASE_SLEEP = 2.0
-_DEFAULT_MAX_SLEEP = 128.0
-_DEFAULT_SLEEP_GROWTH = 2.0
-_DEFAULT_TIMEOUT = None
+_BASE_SLEEP = 2.0
+_MAX_SLEEP = 128.0
+_SLEEP_GROWTH = 2.0
+_TIMEOUT = None
 
 
 class QcticResultTimeoutError(Exception):
@@ -22,11 +22,10 @@ def _raise_if_timeout(start, timeout):
             "Timeout exceeded ({} secs)".format(timeout))
 
 
-def wait_result(job, **kwargs):
-    sleep = kwargs.get("base_sleep", _DEFAULT_BASE_SLEEP)
-    max_sleep = kwargs.get("max_sleep", _DEFAULT_MAX_SLEEP)
-    sleep_growth = kwargs.get("sleep_growth", _DEFAULT_SLEEP_GROWTH)
-    timeout = kwargs.get("timeout", _DEFAULT_TIMEOUT)
+def wait_result(
+        job, base_sleep=_BASE_SLEEP, max_sleep=_MAX_SLEEP,
+        sleep_growth=_SLEEP_GROWTH, timeout=_TIMEOUT):
+    sleep = base_sleep
     start = time.time()
 
     while True:
@@ -40,11 +39,10 @@ def wait_result(job, **kwargs):
         sleep = min(sleep * sleep_growth, max_sleep)
 
 
-async def wait_result_async(job, **kwargs):
-    sleep = kwargs.get("base_sleep", _DEFAULT_BASE_SLEEP)
-    max_sleep = kwargs.get("max_sleep", _DEFAULT_MAX_SLEEP)
-    sleep_growth = kwargs.get("sleep_growth", _DEFAULT_SLEEP_GROWTH)
-    timeout = kwargs.get("timeout", _DEFAULT_TIMEOUT)
+async def wait_result_async(
+        job, base_sleep=_BASE_SLEEP, max_sleep=_MAX_SLEEP,
+        sleep_growth=_SLEEP_GROWTH, timeout=_TIMEOUT):
+    sleep = base_sleep
     start = time.time()
 
     while True:
