@@ -72,6 +72,39 @@ def test_get_jobs(httpserver):
     assert all(item.get("job_id", False) for item in res)
 
 
+def test_get_jobs_arg_status(httpserver):
+    job_dicts = [fake_job_dict() for _ in range(50)]
+
+    def handler(req):
+        return Response(json.dumps([
+            item for item in job_dicts
+            if item["status"] in req.args.getlist("status")
+        ]))
+
+    httpserver.expect_request("/jobs").respond_with_handler(handler)
+    api = _build_api(httpserver)
+
+    status_str = job_dicts[0]["status"]
+
+    res = api.get_jobs_sync(
+        limit=len(job_dicts),
+        skip=0,
+        status=status_str)
+
+    assert all(item["status"] == status_str for item in res)
+
+    status_all = list(set(item["status"] for item in job_dicts))
+    limit_idx = len(status_all) - 1 if len(status_all) > 0 else 1
+    status_list = status_all[:limit_idx]
+
+    res = api.get_jobs_sync(
+        limit=len(job_dicts),
+        skip=0,
+        status=status_list)
+
+    assert all(item["status"] in status_list for item in res)
+
+
 def test_get_backend_status(httpserver):
     httpserver.expect_request("/status").respond_with_json({
         "operational": True,
