@@ -8,12 +8,12 @@ import pytest
 from qiskit import Aer, execute
 from qiskit.assembler import disassemble
 from qiskit.providers import JobStatus
+from tests.utils import fake_job_dict, fake_qobj
 from werkzeug.wrappers import Response
 
 from qctic.backend import QCticQasmSimulator
 from qctic.job import QCticJob
 from qctic.provider import QCticProvider
-from tests.utils import fake_job_dict, fake_qobj
 
 _LOCALHOST = "http://localhost"
 _JOB_DICTS = [fake_job_dict() for _ in range(random.randint(1, 10))]
@@ -112,7 +112,7 @@ def test_backend_run(provider, httpserver):
 
     assert job.job_id()
     assert job.api
-    assert job.qobj.to_dict() == qobj.to_dict()
+    assert job.qobj().to_dict() == qobj.to_dict()
     assert job.run_params[arg_key]
 
 
@@ -218,7 +218,7 @@ def job_for_status_test(job, httpserver):
 
     httpserver.expect_request(url).respond_with_json({
         "job_id": job.job_id(),
-        "qobj": job.qobj.to_dict(),
+        "qobj": job.qobj().to_dict(),
         "date_submit": datetime.datetime.now().isoformat(),
         "status": status
     })
@@ -241,7 +241,7 @@ def job_for_submit_test(job, httpserver):
     def handler(req):
         data = json.loads(req.data)
         assert data["job_id"] == job.job_id()
-        assert data["qobj"] == job.qobj.to_dict()
+        assert data["qobj"] == job.qobj().to_dict()
         return Response()
 
     httpserver.expect_request("/jobs").respond_with_handler(handler)
@@ -281,7 +281,7 @@ async def test_job_cancel_async(job_for_cancel_test):
 
 
 def test_job_result(job, httpserver):
-    circuits, _run_config, _user_qobj_header = disassemble(job.qobj)
+    circuits, _run_config, _user_qobj_header = disassemble(job.qobj())
     simulator = Aer.get_backend("qasm_simulator")
     simulator_job = execute(circuits[0], simulator)
     simulator_result = simulator_job.result()
@@ -290,7 +290,7 @@ def test_job_result(job, httpserver):
 
     httpserver.expect_request(url).respond_with_json({
         "job_id": job.job_id(),
-        "qobj": job.qobj.to_dict(),
+        "qobj": job.qobj().to_dict(),
         "date_submit": now.isoformat(),
         "date_start": (now + datetime.timedelta(1)).isoformat(),
         "date_end": (now + datetime.timedelta(2)).isoformat(),
@@ -306,7 +306,7 @@ def test_job_result(job, httpserver):
 def test_job_fetch_remote(job, httpserver):
     job_dict = {
         "job_id": job.job_id(),
-        "qobj": job.qobj.to_dict(),
+        "qobj": job.qobj().to_dict(),
         "date_submit": datetime.datetime.now().isoformat(),
         "status": JobStatus.INITIALIZING.name
     }
@@ -321,9 +321,9 @@ def test_job_fetch_remote(job, httpserver):
     httpserver.expect_request(url).respond_with_handler(handler)
 
     assert count[0] == 0
-    job.status()
+    assert job.status() == job_dict["status"]
     assert count[0] == 1
-    job.status()
-    assert count[0] == 2
-    job.status(fetch=False)
+    assert job.status() == job_dict["status"]
+    assert count[0] == 1
+    assert job.status(fetch=True) == job_dict["status"]
     assert count[0] == 2
